pub struct StaticModel { /* private fields */ }Expand description
Static embedding model for Model2Vec
Implementations
Sourceimpl StaticModel
impl StaticModel
Sourcepub fn from_pretrained<P: AsRef<Path>>(
repo_or_path: P,
token: Option<&str>,
normalize: Option<bool>,
subfolder: Option<&str>,
) -> Result<Self>
pub fn from_pretrained<P: AsRef<Path>>( repo_or_path: P, token: Option<&str>, normalize: Option<bool>, subfolder: Option<&str>, ) -> Result<Self>
Load a Model2Vec model from a local folder or the HuggingFace Hub.
Arguments
repo_or_path- HuggingFace repo ID or local path to the model folder.token- Optional HuggingFace token for authenticated downloads.normalize- Optional flag to normalize embeddings (default from config.json).subfolder- Optional subfolder within the repo or path to look for model files.
Sourcepub fn encode_with_args(
&self,
sentences: &[String],
max_length: Option<usize>,
batch_size: usize,
) -> Vec<Vec<f32>>
pub fn encode_with_args( &self, sentences: &[String], max_length: Option<usize>, batch_size: usize, ) -> Vec<Vec<f32>>
Encode texts into embeddings.
Arguments
sentences- the list of sentences to encode.max_length- max tokens per text.batch_size- number of texts per batch.
Sourcepub fn encode(&self, sentences: &[String]) -> Vec<Vec<f32>>
pub fn encode(&self, sentences: &[String]) -> Vec<Vec<f32>>
Default encode: max_length=512, batch_size=1024
pub fn encode_single(&self, sentence: &str) -> Vec<f32>